@@ -2,6 +2,9 @@
 
 void Decryptor::getPassphrase()
 {
+    if (not d_passphrase.empty())
+        return;
+
     struct termios ttySaved;
 
     int fd = echo(&ttySaved);       // switch off echoing, fd to /dev/tty
