@@ -5,19 +5,22 @@ int Decryptor::insertPGPsection(Process &gpg, string const &pgpHeader,
 {
     gpg.start();
 
+    if (d_msg)
+        *d_msg << fileInfo() << ": PGP HEADER" << endl;
+
     gpg << pgpHeader << '\n';
+
     string line;
+
     do
     {
-        getline(in, line);
+        nextline(in, line);
         gpg << line << '\n';
     }
     while (line.find("-----END PGP MESSAGE-----") != 0);
 
     gpg.close();
-    int ret = gpg.waitForChild();
-
-    (d_msgName == "-" ? cerr : d_msg)  << gpg.childErrStream().rdbuf();
-
-    return ret;
+    return gpg.waitForChild();
 }
+
+
