@@ -8,8 +8,9 @@ void Guncat::processFileArguments()
             processCin();
         else
         {
+            g_filename = d_arg[idx];
             ifstream in;
-            Exception::open(in, d_arg[idx]);
+            Exception::open(in, g_filename);
             process(in);
         }
     }
