@@ -4,14 +4,16 @@ namespace
 {
     Arg::LongOption longOptions[] =
     {
+        Arg::LongOption("errors-OK",    Arg::None),
         Arg::LongOption("gpg",          Arg::Required),
-        Arg::LongOption("passphrase",   'p'),
-        Arg::LongOption("gpg-no-batch", Arg::None),
         Arg::LongOption("gpg-msg",      'm'),
+        Arg::LongOption("gpg-no-batch", Arg::None),         // deprecated
         Arg::LongOption("gpg-option",   Arg::Required),
         Arg::LongOption("help",         'h'),
         Arg::LongOption("locate-keys",  'l'),
+        Arg::LongOption("passphrase",   'p'),
         Arg::LongOption("show-gpg",     Arg::None),
+        Arg::LongOption("time-limit",   'T'),
         Arg::LongOption("tty-OK",       't'),
         Arg::LongOption("verbose",      Arg::Required),
         Arg::LongOption("version",      'v'),
@@ -22,9 +24,9 @@ namespace
 int main(int argc, char **argv)
 try
 {
-    Arg &arg = Arg::initialize("m:hlptv", longOptions, longEnd, argc, argv);
+    Arg &arg = Arg::initialize("m:hlptT:v", longOptions, longEnd, argc, argv);
     arg.versionHelp(usage, version, 0);
-    
+
     Guncat guncat;
     guncat.arguments();
 }
